==> spikesafe_python-1.8.3.tar.gz: spikesafe_python-1.8.3/spikesafe_python/SpikeSafeEvents.py <==
from enum import IntEnum

class SpikeSafeEvents(IntEnum):
    """
    SpikeSafe event options for the SpikeSafe
    """
    OK = 0
    DIGITIZER_INVALID_COMMAND = 99
    CHANNEL_READY = 100
    EXTERNAL_PAUSE_SIGNAL_STARTED = 101
    EXTERNAL_PAUSE_SIGNAL_ENDED = 102
    REMOTE_DISABLE_ACTIVE = 103
    CURRENT_RANGE_SWITCHED_MANUALLY_PLEASE_RESET_CURRENT = 104
    MODULATED_SEQ_IS_COMPLETED = 105
    SETTING_SAVED_COMPENSATION_FORCED_TO_VERY_LOW_VERY_SLOW_IN_DC_MODES = 106
    REMOTE_DISABLE_CHANNEL_ACTIVE = 107
    PULSED_SWEEP_COMPLETE = 109
    PULSED_SWEEP_SHUT_DOWN_DUE_TO_ERROR = 110
    COMPENSATION_IS_RESTORED = 114
    PULSE_WIDTH_ADJUSTMENT_IS_DISABLED_IN_THIS_STATE = 115
    ACCESS_TO_EFP_IS_NOT_ALLOWED = 116
    PULSE_SETTINGS_ON_TIME_OFF_TIME_AND_OFFSET_ARE_RESET_TO_DEFAULT = 117
    OFF_TIME_EXCEEDED_RANGE = 118
    PULSE_WIDTH_OFFSET_EXCEEDED_RANGE = 119
    MULTIPLE_PULSE_BURST_COMPLETE = 120
    MULTIPLE_PULSE_BURST_SHUT_DOWN_DUE_TO_ERROR = 121
    MULTIPLE_PULSE_BURST_MODE_SET_EXTERNAL_SOURCE_TRIGGER_OUT_FORCED_TO_ALWAYS_AND_MULTIPLE_PULSE_TRIGGER_OUT_FORCED_TO_ONE = 122
    MAC_ADDRESS_IS_NOT_CONFIGURED = 123
    NO_EXTERNAL_SOURCE_TRIGGER_OUTPUT_DUE_TO_PULSE_WIDTH_ADJUSTMENT_IS_DISABLED_INTERNALLY = 124
    MAX_COMPLIANCE_VOLTAGE_EXCEEDED_LIMIT = 125
    MAX_COMPLIANCE_VOLTAGE_EXCEEDED = 200
    HIGH_SIDE_OVER_CURRENT = 201
    LOW_SIDE_OVER_CURRENT = 202
    VOLTAGE_RAMP_DETECTED = 204
    LEAKAGE_FROM_EXTERNAL_SOURCE = 205
    OVER_VOLTAGE = 206
    CURRENT_LEAKAGE_DETECTED = 207
    EXCESSIVE_INTERNAL_VOLTAGE = 208
    INTERNAL_COMMUNICATION_ERROR = 300
    INSUFFICIENT_BULK_VOLTAGE = 301
    INVALID_CHANNEL_ARGUMENT = 302
    INVALID_CURRENT_SETTING = 303
    INVALID_VOLTAGE_SETTING = 304
    INVALID_OUTPUT_STATE = 305
    INVALID_COMMAND = 306
    INVALID_DV_SETTING = 307
    INVALID_DT_SETTING = 308
    ONE_OR_MORE_CHANNELS_ENABLED_CANNOT_CHANGE_SETTING = 309
    CHANNEL_IS_ENABLED_CANNOT_CHANGE_SETTING = 310
    INVALID_DV_DT_STATE = 311
    INVALID_OVER_CURRENT_LEVEL = 312
    DSP_VERSIONS_DO_NOT_MATCH = 313
    INTERNAL_OVER_POWER = 314
    INTERNAL_OVER_TEMPERATURE_ERROR = 316
    INTERNAL_BULK_OVER_CURRENT = 317
    MAXIMUM_BULK_VOLTAGE_BOOST_EXCEEDED = 318
    INVALID_CURRENT_RANGE = 320
    INVALID_CURRENT_RANGE_AUTO = 321
    INVALID_PULSE_MODE = 322
    INVALID_PULSE_ON_TIME_SETTING = 323
    INVALID_CABLE_COMPENSATION_SETTING = 324
    UNEXPECTED_DSP_REPLY = 325
    CHANNEL_ENABLE_COULD_EXCEED_GROUP_POWER = 326
    CHANNEL_ENABLE_COULD_EXCEED_MAX_POWER = 327
    CAN_NOT_CHANGE_CURRENT_RANGE_WHILE_CHANNEL_IS_ENABLED = 328
    PULSE_WIDTH_ADJUSTMENT_ERROR = 329
    CHANNEL_ENABLE_COULD_EXCEED_COMBINED_POWER_LIMIT_FOR_CHANNELS_1_4 = 330
    CHANNEL_ENABLE_COULD_EXCEED_COMBINED_POWER_LIMIT_FOR_CHANNELS_5_8 = 331
    EXCESSIVE_BULK_VOLTAGE = 332
    INVALID_ARGUMENT = 336
    INVALID_RISE_TIME_SETTING = 337
    INVALID_STAGGER_STATE = 339
    INVALID_PULSE_WIDTH_ADJUSTMENT_STATE = 340
    INVALID_DUTY_CYCLE = 341
    INVALID_PERIOD = 342
    INVALID_PULSE_WIDTH = 343
    INVALID_PULSE_HOLD_SETTING = 344
    INVALID_PULSE_OFF_TIME_SETTING = 345
    DUTY_CYCLE_WOULD_EXCEED_ON_OR_OFF_TIME_MAXIMUM = 346
    PERIOD_WOULD_EXCEED_ON_OR_OFF_TIME_MAXIMUM = 347
    PULSE_WIDTH_WOULD_EXCEED_ON_OR_OFF_TIME_MAXIMUM = 348
    INVALID_TRIGGER_SLOPE_SETTING = 350
    CHANNEL_NOT_READY = 351
    INVALID_PULSE_COUNT = 352
    PULSING_NOT_READY = 353
    BIAS_CURRENT_OVER_POWER = 354
    INVALID_BIAS_CURRENT = 355
    EXCEED_MAX_PERCENT = 356
    EXCEED_MAX_SEQ_STEPS = 357
    INVALID_SEQUENCE = 358
    EXCEED_MAX_SEQ_DEPTH = 359
    CANNOT_START_CHANNEL_UNTIL_CURRENT_SET_POINT_CHANGED = 360
    UNSTABLE_CURRENT_WAVEFORM = 361
    INVALID_RAMP_RATE_SETTING = 362
    UNEXPECTED_VOLTAGE_PRESENT_ON_HIGH_SIDE = 363
    INVALID_TRIGGER_ARGUMENT = 364
    INVALID_SYNC_STATE = 365
    INVALID_TIMEOUT_STATE = 366
    CANNOT_START_CHANNEL_UNTIL_START_AND_END_CURRENT_SET_POINT_CHANGED = 367
    CANNOT_START_CHANNEL_UNTIL_PULSE_TIME_SETTINGS_CHANGED = 368
    COMMAND_NOT_AVAILABLE_ON_THIS_MODEL = 369
    INVALID_PULSE_WIDTH_OFFSET = 370
    INVALID_TRIGGER_DELAY = 371
    INVALID_TRIGGER_POLARITY_SETTING = 372
    INVALID_TRIGGER_SOURCE_SETTING = 373
    CANNOT_SET_BELOW_300US_PERIOD_IN_PULSED_SWEEP_MODES = 374
    CANNOT_SET_BELOW_10US_PERIOD_IN_ANY_PULSE_MODE = 375
    I2C_BUFFER_OVERFLOW = 376
    I2C_BAD_COMMAND = 377
    BULK_POWER_FAILURE = 378
    PULSE_OFF_TIME_IS_LESS_THAN_1US_WITH_OFFSET = 379
    PULSE_ON_TIME_IS_LESS_THAN_01_US_WITH_OFFSET = 380
    CANNOT_SET_ON_TIME_ABOVE_10S_OR_OFF_TIME_ABOVE_30S_IN_PULSED_SWEEP_OR_MULTI_PULSE_MODES = 381
    TRIGGER_SETTING_IS_NOT_ALLOWED_IF_ANY_CHANNELS_ENABLED = 382
    CANNOT_CHANGE_PULSE_TIMES_DYNAMICALLY = 383
    CONFIGURATION_INVALID_AND_HAS_NOT_BEEN_WRITTEN_TO_FLASH_MEMORY = 384
    OUTPUT_SWITCH_CANNOT_BE_CHANGED_UNTIL_CHANNEL_DISABLED_OR_NO_CURRENT = 385
    OUTPUT_SWITCH_IS_NOT_INSTALLED = 386
    INVALID_MULTIPLE_PULSE_BURST_COUNT = 387
    INVALID_MULTIPLE_PULSE_RETRIGGER_TIME_OFF = 388
    DIGITIZER_VERSION_NOT_MATCH = 389
    INVALID_SCIENTIFIC_NOTATION = 392
    INVALID_OFF_TIME_CAUSED_BY_INVALID_PULSE_WIDTH_CORRECTION = 395
    INVALID_ON_TIME_CAUSED_BY_INVALID_PULSE_WIDTH_CORRECTION = 396
    CHANNEL_IS_PULSING_CANNOT_CHANGE_SETTING = 397
    COMMUNICATION_ERROR_DURING_IDN_QUERY_I2C_IS_RESET = 398
    CPLD_VERSIONS_DO_NOT_MATCH = 399
    DIGITIZER_INVALID_APERTURE = 401
    DIGITIZER_INVALID_READ_COUNT = 402
    DIGITIZER_INVALID_TRIGGER_COUNT = 403
    DIGITIZER_INVALID_TRIGGER_DELAY = 404
    DIGITIZER_INVALID_TRIGGER_SOURCE = 405
    DIGITIZER_INVALID_TRIGGER_EDGE = 406
    DIGITIZER_INVALID_RANGE = 407
    DIGITIZER_INVALID_RUN_SETTING = 409
    DIGITIZER_MISSING_APERTURE_PARAMETER = 410
    DIGITIZER_MISSING_RANGE_PARAMETER = 411
    DIGITIZER_MISSING_TRIGGER_COUNT_PARAMETER = 412
    DIGITIZER_MISSING_TRIGGER_DELAY_PARAMETER = 413
    DIGITIZER_MISSING_TRIGGER_EDGE_PARAMETER = 414
    DIGITIZER_MISSING_TRIGGER_SOURCE_PARAMETER = 415
    DIGITIZER_MISSING_READ_COUNT_PARAMETER = 416
    DIGITIZER_OVER_RANGE_TRIPPED = 418
    DIGITIZER_INVALID_STATE = 419
    DIGITIZER_RECEIVE_BUFFER_OVERFLOW = 420
    DIGITIZER_INVALID_OUTPUT_TRIGGER_EDGE = 421
    DIGITIZER_INVALID_TRIGGER_SOURCE_422 = 422
    DIGITIZER_INVALID_SAMPLING_MODE_SETTING = 423
    DIGITIZER_MISSING_SAMPLING_MODE_PARAMETER = 424
    DIGITIZER_MISSING_ENABLING_RAW_DATA_PARAMETER = 425
    DIGITIZER_INVALID_ENABLING_RAW_DATA_SETTING = 426
    DIGITIZER_RAW_DATA_NOT_ENABLED = 427
    DIGITIZER_ENABLING_RAW_DATA_REQUIRES_MEASUREMENT_SEQUENCE_TO_BE_IDLE = 428
    DIGITIZER_INVALID_OUTPUT_TRIGGER_DELAY = 429
    DIGITIZER_MISSING_OUTPUT_TRIGGER_DELAY_PARAMETER = 430
    DIGITIZER_THE_INPUT_RELAYS_OF_THE_DEVICE_IS_DISCONNECTED = 431
    DIGITIZER_MISSING_OUTPUT_TRIGGER_EDGE_PARAMETER = 432
    SAMPLING_CUSTOM_SEQUENCE_IS_NOT_SET = 433
    INVALID_VOLTAGE_PROTECTION_MODE = 500
    EXCEED_MAX_TOTAL_NUMBER_OF_STEPS_IN_SAMPLING_CUSTOM_SEQUENCE = 501
    INVALID_SAMPLING_CUSTOM_SEQUENCE = 502
    EXCEED_MAX_TOTAL_READ_COUNT_IN_SAMPLING_CUSTOM_SEQUENCE = 503
    EXCEED_MAX_SAMPLING_CUSTOM_SEQUENCE_STRING_LENGTH = 504
    EXCEED_MAX_TOTAL_SAMPLING_TIME_IN_SAMPLING_CUSTOM_SEQUENCE = 505
    EXCEED_MAX_TOTAL_SAMPLING_CUSTOM_SEQUENCE_STRING_LENGTH = 506
    PREVIOUS_SEQUENCE_HAVE_NOT_BEEN_CLEARED = 507
    NO_SEQUENCE_HAVE_BEEN_SET = 508
    EXCEED_MAX_SAMPLING_CUSTOM_SEQUENCE_APERTURE = 509

==> spikesafe_python-1.10.2.tar.gz: spikesafe_python-1.10.2/spikesafe_python/SpikeSafeEvents.py <==
from enum import IntEnum

class SpikeSafeEvents(IntEnum):
    """
    SpikeSafe event options for the SpikeSafe
    """
    OK = 0
    DIGITIZER_INVALID_COMMAND = 99
    CHANNEL_READY = 100
    EXTERNAL_PAUSE_SIGNAL_STARTED = 101
    EXTERNAL_PAUSE_SIGNAL_ENDED = 102
    REMOTE_DISABLE_ACTIVE = 103
    CURRENT_RANGE_SWITCHED_MANUALLY_PLEASE_RESET_CURRENT = 104
    MODULATED_SEQ_IS_COMPLETED = 105
    SETTING_SAVED_COMPENSATION_FORCED_TO_VERY_LOW_VERY_SLOW_IN_DC_MODES = 106
    REMOTE_DISABLE_CHANNEL_ACTIVE = 107
    PULSED_SWEEP_COMPLETE = 109
    PULSED_SWEEP_SHUT_DOWN_DUE_TO_ERROR = 110
    COMPENSATION_IS_RESTORED = 114
    PULSE_WIDTH_ADJUSTMENT_IS_DISABLED_IN_THIS_STATE = 115
    ACCESS_TO_EFP_IS_NOT_ALLOWED = 116
    PULSE_SETTINGS_ON_TIME_OFF_TIME_AND_OFFSET_ARE_RESET_TO_DEFAULT = 117
    OFF_TIME_EXCEEDED_RANGE = 118
    PULSE_WIDTH_OFFSET_EXCEEDED_RANGE = 119
    MULTIPLE_PULSE_BURST_COMPLETE = 120
    MULTIPLE_PULSE_BURST_SHUT_DOWN_DUE_TO_ERROR = 121
    MULTIPLE_PULSE_BURST_MODE_SET_EXTERNAL_SOURCE_TRIGGER_OUT_FORCED_TO_ALWAYS_AND_MULTIPLE_PULSE_TRIGGER_OUT_FORCED_TO_ONE = 122
    MAC_ADDRESS_IS_NOT_CONFIGURED = 123
    NO_EXTERNAL_SOURCE_TRIGGER_OUTPUT_DUE_TO_PULSE_WIDTH_ADJUSTMENT_IS_DISABLED_INTERNALLY = 124
    MAX_COMPLIANCE_VOLTAGE_EXCEEDED_LIMIT = 125
    MAX_COMPLIANCE_VOLTAGE_EXCEEDED = 200
    HIGH_SIDE_OVER_CURRENT = 201
    LOW_SIDE_OVER_CURRENT = 202
    VOLTAGE_RAMP_DETECTED = 204
    LEAKAGE_FROM_EXTERNAL_SOURCE = 205
    OVER_VOLTAGE = 206
    CURRENT_LEAKAGE_DETECTED = 207
    EXCESSIVE_INTERNAL_VOLTAGE = 208
    INTERNAL_BULK_OVER_CURRENT = 209
    MAXIMUM_BULK_VOLTAGE_BOOST_EXCEEDED = 210
    PULSE_WIDTH_ADJUSTMENT_ERROR = 211
    EXCESSIVE_BULK_VOLTAGE = 212
    BULK_POWER_FAILURE = 213
    INTERNAL_COMMUNICATION_ERROR = 300
    INSUFFICIENT_BULK_VOLTAGE = 301
    INVALID_CHANNEL_ARGUMENT = 302
    INVALID_CURRENT_SETTING = 303
    INVALID_VOLTAGE_SETTING = 304
    INVALID_OUTPUT_STATE = 305
    INVALID_COMMAND = 306
    INVALID_DV_SETTING = 307
    INVALID_DT_SETTING = 308
    ONE_OR_MORE_CHANNELS_ENABLED_CANNOT_CHANGE_SETTING = 309
    CHANNEL_IS_ENABLED_CANNOT_CHANGE_SETTING = 310
    INVALID_DV_DT_STATE = 311
    INVALID_OVER_CURRENT_LEVEL = 312
    DSP_VERSIONS_DO_NOT_MATCH = 313
    INTERNAL_OVER_POWER = 314
    INTERNAL_OVER_TEMPERATURE_ERROR = 316
    # Deprecated starting with Ethernet Processor version 3.0.11.10: Use INTERNAL_BULK_OVER_CURRENT (209)
    INTERNAL_BULK_OVER_CURRENT_OLD = 317
    # Deprecated starting with Ethernet Processor version 3.0.11.10: Use MAX_BULK_VOLTAGE_BOOST_EXCEEDED (210)
    MAXIMUM_BULK_VOLTAGE_BOOST_EXCEEDED_OLD = 318
    INVALID_CURRENT_RANGE = 320
    INVALID_CURRENT_RANGE_AUTO = 321
    INVALID_PULSE_MODE = 322
    INVALID_PULSE_ON_TIME_SETTING = 323
    INVALID_CABLE_COMPENSATION_SETTING = 324
    UNEXPECTED_DSP_REPLY = 325
    CHANNEL_ENABLE_COULD_EXCEED_GROUP_POWER = 326
    CHANNEL_ENABLE_COULD_EXCEED_MAX_POWER = 327
    CAN_NOT_CHANGE_CURRENT_RANGE_WHILE_CHANNEL_IS_ENABLED = 328
    # Deprecated starting with Ethernet Processor version 3.0.11.10: Use PULSE_WIDTH_ADJUSTMENT_ERROR (211)
    PULSE_WIDTH_ADJUSTMENT_ERROR_OLD = 329
    CHANNEL_ENABLE_COULD_EXCEED_COMBINED_POWER_LIMIT_FOR_CHANNELS_1_4 = 330
    CHANNEL_ENABLE_COULD_EXCEED_COMBINED_POWER_LIMIT_FOR_CHANNELS_5_8 = 331
    # Deprecated starting with Ethernet Processor version 3.0.11.10: Use EXCESSIVE_BULK_VOLTAGE (212)
    EXCESSIVE_BULK_VOLTAGE_OLD = 332
    INVALID_ARGUMENT = 336
    INVALID_RISE_TIME_SETTING = 337
    INVALID_STAGGER_STATE = 339
    INVALID_PULSE_WIDTH_ADJUSTMENT_STATE = 340
    INVALID_DUTY_CYCLE = 341
    INVALID_PERIOD = 342
    INVALID_PULSE_WIDTH = 343
    INVALID_PULSE_HOLD_SETTING = 344
    INVALID_PULSE_OFF_TIME_SETTING = 345
    DUTY_CYCLE_WOULD_EXCEED_ON_OR_OFF_TIME_MAXIMUM = 346
    PERIOD_WOULD_EXCEED_ON_OR_OFF_TIME_MAXIMUM = 347
    PULSE_WIDTH_WOULD_EXCEED_ON_OR_OFF_TIME_MAXIMUM = 348
    INVALID_TRIGGER_SLOPE_SETTING = 350
    CHANNEL_NOT_READY = 351
    INVALID_PULSE_COUNT = 352
    PULSING_NOT_READY = 353
    BIAS_CURRENT_OVER_POWER = 354
    INVALID_BIAS_CURRENT = 355
    EXCEED_MAX_PERCENT = 356
    EXCEED_MAX_SEQ_STEPS = 357
    INVALID_SEQUENCE = 358
    EXCEED_MAX_SEQ_DEPTH = 359
    CANNOT_START_CHANNEL_UNTIL_CURRENT_SET_POINT_CHANGED = 360
    UNSTABLE_CURRENT_WAVEFORM = 361
    INVALID_RAMP_RATE_SETTING = 362
    UNEXPECTED_VOLTAGE_PRESENT_ON_HIGH_SIDE = 363
    INVALID_TRIGGER_ARGUMENT = 364
    INVALID_SYNC_STATE = 365
    INVALID_TIMEOUT_STATE = 366
    CANNOT_START_CHANNEL_UNTIL_START_AND_END_CURRENT_SET_POINT_CHANGED = 367
    CANNOT_START_CHANNEL_UNTIL_PULSE_TIME_SETTINGS_CHANGED = 368
    COMMAND_NOT_AVAILABLE_ON_THIS_MODEL = 369
    INVALID_PULSE_WIDTH_OFFSET = 370
    INVALID_TRIGGER_DELAY = 371
    INVALID_TRIGGER_POLARITY_SETTING = 372
    INVALID_TRIGGER_SOURCE_SETTING = 373
    CANNOT_SET_BELOW_300US_PERIOD_IN_PULSED_SWEEP_MODES = 374
    CANNOT_SET_BELOW_10US_PERIOD_IN_ANY_PULSE_MODE = 375
    I2C_BUFFER_OVERFLOW = 376
    I2C_BAD_COMMAND = 377
    # Deprecated starting with Ethernet Processor version 3.0.11.10: Use BULK_POWER_FAILURE (213)
    BULK_POWER_FAILURE_OLD = 378
    PULSE_OFF_TIME_IS_LESS_THAN_1US_WITH_OFFSET = 379
    PULSE_ON_TIME_IS_LESS_THAN_01_US_WITH_OFFSET = 380
    CANNOT_SET_ON_TIME_ABOVE_10S_OR_OFF_TIME_ABOVE_30S_IN_PULSED_SWEEP_OR_MULTI_PULSE_MODES = 381
    TRIGGER_SETTING_IS_NOT_ALLOWED_IF_ANY_CHANNELS_ENABLED = 382
    CANNOT_CHANGE_PULSE_TIMES_DYNAMICALLY = 383
    CONFIGURATION_INVALID_AND_HAS_NOT_BEEN_WRITTEN_TO_FLASH_MEMORY = 384
    OUTPUT_SWITCH_CANNOT_BE_CHANGED_UNTIL_CHANNEL_DISABLED_OR_NO_CURRENT = 385
    OUTPUT_SWITCH_IS_NOT_INSTALLED = 386
    INVALID_MULTIPLE_PULSE_BURST_COUNT = 387
    INVALID_MULTIPLE_PULSE_RETRIGGER_TIME_OFF = 388
    DIGITIZER_VERSION_NOT_MATCH = 389
    INVALID_SCIENTIFIC_NOTATION = 392
    INVALID_OFF_TIME_CAUSED_BY_INVALID_PULSE_WIDTH_CORRECTION = 395
    INVALID_ON_TIME_CAUSED_BY_INVALID_PULSE_WIDTH_CORRECTION = 396
    CHANNEL_IS_PULSING_CANNOT_CHANGE_SETTING = 397
    COMMUNICATION_ERROR_DURING_IDN_QUERY_I2C_IS_RESET = 398
    CPLD_VERSIONS_DO_NOT_MATCH = 399
    DIGITIZER_INVALID_APERTURE = 401
    DIGITIZER_INVALID_READ_COUNT = 402
    DIGITIZER_INVALID_TRIGGER_COUNT = 403
    DIGITIZER_INVALID_TRIGGER_DELAY = 404
    DIGITIZER_INVALID_TRIGGER_SOURCE = 405
    DIGITIZER_INVALID_TRIGGER_EDGE = 406
    DIGITIZER_INVALID_RANGE = 407
    DIGITIZER_INVALID_RUN_SETTING = 409
    DIGITIZER_MISSING_APERTURE_PARAMETER = 410
    DIGITIZER_MISSING_RANGE_PARAMETER = 411
    DIGITIZER_MISSING_TRIGGER_COUNT_PARAMETER = 412
    DIGITIZER_MISSING_TRIGGER_DELAY_PARAMETER = 413
    DIGITIZER_MISSING_TRIGGER_EDGE_PARAMETER = 414
    DIGITIZER_MISSING_TRIGGER_SOURCE_PARAMETER = 415
    DIGITIZER_MISSING_READ_COUNT_PARAMETER = 416
    DIGITIZER_OVER_RANGE_TRIPPED = 418
    DIGITIZER_INVALID_STATE = 419
    DIGITIZER_RECEIVE_BUFFER_OVERFLOW = 420
    DIGITIZER_INVALID_OUTPUT_TRIGGER_EDGE = 421
    DIGITIZER_INVALID_TRIGGER_SOURCE_422 = 422
    DIGITIZER_INVALID_SAMPLING_MODE_SETTING = 423
    DIGITIZER_MISSING_SAMPLING_MODE_PARAMETER = 424
    DIGITIZER_MISSING_ENABLING_RAW_DATA_PARAMETER = 425
    DIGITIZER_INVALID_ENABLING_RAW_DATA_SETTING = 426
    DIGITIZER_RAW_DATA_NOT_ENABLED = 427
    DIGITIZER_ENABLING_RAW_DATA_REQUIRES_MEASUREMENT_SEQUENCE_TO_BE_IDLE = 428
    DIGITIZER_INVALID_OUTPUT_TRIGGER_DELAY = 429
    DIGITIZER_MISSING_OUTPUT_TRIGGER_DELAY_PARAMETER = 430
    DIGITIZER_THE_INPUT_RELAYS_OF_THE_DEVICE_IS_DISCONNECTED = 431
    DIGITIZER_MISSING_OUTPUT_TRIGGER_EDGE_PARAMETER = 432
    SAMPLING_CUSTOM_SEQUENCE_IS_NOT_SET = 433
    INVALID_PARTIAL_ABORT = 434
    # Deprecated starting with Ethernet Processor version 3.0.11.10: Use INVALID_VOLTAGE_PROTECTION_MODE (600)
    INVALID_VOLTAGE_PROTECTION_MODE_OLD = 500
    EXCEED_MAX_TOTAL_NUMBER_OF_STEPS_IN_SAMPLING_CUSTOM_SEQUENCE = 501
    INVALID_SAMPLING_CUSTOM_SEQUENCE = 502
    EXCEED_MAX_TOTAL_READ_COUNT_IN_SAMPLING_CUSTOM_SEQUENCE = 503
    EXCEED_MAX_SAMPLING_CUSTOM_SEQUENCE_STRING_LENGTH = 504
    EXCEED_MAX_TOTAL_SAMPLING_TIME_IN_SAMPLING_CUSTOM_SEQUENCE = 505
    EXCEED_MAX_TOTAL_SAMPLING_CUSTOM_SEQUENCE_STRING_LENGTH = 506
    PREVIOUS_SEQUENCE_HAVE_NOT_BEEN_CLEARED = 507
    NO_SEQUENCE_HAVE_BEEN_SET = 508
    EXCEED_MAX_SAMPLING_CUSTOM_SEQUENCE_APERTURE = 509
    CANNOT_COMMUNICATE_WITH_DIGITIZER = 510
    INVALID_VOLTAGE_PROTECTION_MODE = 600
